Simulations — waveformtools 2022-05-03 documentation

# Simulations

This is a class to conveniently access, handle and retrieve information and data from Numerical Relativity smulations.

The sim class provides a basic information and data storage container functionality and methods for handling the NR data. Presently the class reads in attributes like

1. component masses,

2. spins,

3. waveforms,

4. time stepping,

5. merger time,

6. data duration,

7. coordinate positions of the centroids of the black holes